![GitHub Banner](https://github.com/langfuse/langfuse-python/assets/2834609/3c36488e-6fe6-4a82-b0f5-5419250ddf86)

# Aigentsphere Python SDK

[![MIT License](https://img.shields.io/badge/License-MIT-red.svg?style=flat-square)](https://opensource.org/licenses/MIT)
[![PyPI Version](https://img.shields.io/pypi/v/aigentsphere.svg?style=flat-square&label=pypi+aigentsphere)](https://pypi.org/project/aigentsphere/)

## Installation

```
pip install aigentsphere
```

## Docs

Coming soon.
